import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/locale/localizations_delegate.dart';
import 'package:vaycore/utils.dart';
import 'package:vaycore/vaycore.dart';

import 'l10n/localizations.dart';
import 'l10n/str_ids.dart';
import 'ui/view/home_page.dart';
import 'viewmodel/config/locale_model.dart';
import 'viewmodel/config/theme_model.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-06-03
///

/// 应用主类
class Application extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    // 白色状态栏图标
    BarUtils.setStatusBarStyle(false);
    return MultiProvider(
      providers: [
        ChangeNotifierProvider.value(value: get<ThemeModel>()),
        ChangeNotifierProvider.value(value: get<LocaleModel>()),
      ],
      child: Consumer2<ThemeModel, LocaleModel>(
        builder: (BuildContext context, themeModel, localeModel, Widget child) {
          return _buildMaterialApp(themeModel, localeModel);
        },
      ),
    );
  }

  MaterialApp _buildMaterialApp(themeModel, localeModel) {
    return MaterialApp(
      theme: ThemeData(
        primarySwatch: themeModel.theme,
      ),
      locale: localeModel.locale,
      home: Scaffold(
        appBar: AppBar(title: Text(getString(StrIds.hello_vaycore))),
        body: HomePage(),
      ),
      localizationsDelegates: [
        // 在项目pubspec.yaml中引入：
        // ```
        //   flutter_localizations:
        //    sdk: flutter
        // ```
        // 后添加这两行注释的代码
        /*GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,*/
        CoreLocalizationsDelegate.delegate,
      ],
      supportedLocales: core.options.locale.supportLocales,
      localeResolutionCallback: (locale, supportedLocales) =>
          core.options.locale.buildLocaleResolutionCallback(
              localeModel.locale, locale, supportedLocales),
    );
  }
}
