import 'dart:io';

import 'package:path_provider/path_provider.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-10
///
class PathUtils {
  /// 不允许实例化
  PathUtils._();

  /// 获取应用程序的文档目录
  static Future<String> getAppDir() async {
    Directory directory = await getApplicationDocumentsDirectory();
    _checkAndCreate(directory);
    return directory.path;
  }

  /// 获取应用程序的临时目录
  static Future<String> getAppTempDir() async {
    Directory directory = await getTemporaryDirectory();
    _checkAndCreate(directory);
    return directory.path;
  }

  /// 获取外部Sdcard目录，在IOS上会抛出异常
  static Future<String> getSdcardDir() async {
    Directory directory = await getExternalStorageDirectory();
    return directory.path;
  }

  /// 检查并创建目录（不存在此目录则创建）
  static _checkAndCreate(Directory directory) {
    if (!directory.existsSync()) {
      directory.createSync(recursive: true);
    }
  }
}
