import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:vaycore/utils.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-18
///

/// toast工具类
class ToastUtils {
  /// 空字符时显示
  static const String NULL = "null";

  /// 不允许初始化
  ToastUtils._();

  /// 显示较短时间toast
  static short(String msg) {
    toast(msg: msg, toastLength: Toast.LENGTH_SHORT);
  }

  /// 显示较长时间toast
  static long(String msg) {
    toast(msg: msg, toastLength: Toast.LENGTH_LONG);
  }

  /// 取消toast
  static cancel() {
    Fluttertoast.cancel();
  }

  /// 定义显示toast
  static toast(
      {@required String msg,
      Toast toastLength = Toast.LENGTH_SHORT,
      int timeInSecForIosWeb = 1,
      double fontSize = 16.0,
      ToastGravity gravity = ToastGravity.BOTTOM,
      Color backgroundColor = Colors.black54,
      Color textColor = Colors.white,
      bool webShowClose = false,
      webBgColor: "linear-gradient(to right, #00b09b, #96c93d)",
      webPosition: "right"}) async {
    Fluttertoast.showToast(
      msg: StringUtils.isEmpty(msg) ? NULL : msg,
      toastLength: toastLength,
      timeInSecForIosWeb: timeInSecForIosWeb,
      fontSize: fontSize,
      gravity: gravity,
      backgroundColor: backgroundColor,
      textColor: textColor,
      webShowClose: webShowClose,
      webBgColor: webBgColor,
      webPosition: webPosition,
    );
  }
}
